NAME

Google::Ai::Generativelanguage::V1 - Auto-generated client library for Google Cloud Services

SYNOPSIS

use Google::Ai::Generativelanguage::V1;
use Google::Auth;

# Initialize Application Default Credentials (ADC) or explicit Google Auth
my $auth = Google::Auth->default();
my $client = Google::Ai::Generativelanguage::V1->new( credentials => $auth );

# Execute service methods
my $res = $client->some_method( %params );

DESCRIPTION

This is an auto-generated Protocol Buffers client library for Google Cloud Services, built on top of high-performance gRPC and Protocol Buffers!

It provides seamless integration with Google Cloud Application Default Credentials (ADC), support for both HTTP/2 gRPC and REST transports, and fully typed RPC method dispatching.

CONSTRUCTOR

new

my $client = Google::Ai::Generativelanguage::V1->new(
    credentials => $auth,       # Optional: Google::Auth object (defaults to ADC)
    transport   => 'grpc',     # Optional: 'grpc' (default) or 'rest'
);

METHODS

The following RPC methods are available in this client:

METHODS

The following RPC methods are available in this client:

  • generate_content

    Calls the RPC method GenerateContent on the service. Takes a hash of parameters representing the request.

  • embed_content

    Calls the RPC method EmbedContent on the service. Takes a hash of parameters representing the request.

  • batch_embed_contents

    Calls the RPC method BatchEmbedContents on the service. Takes a hash of parameters representing the request.

  • count_tokens

    Calls the RPC method CountTokens on the service. Takes a hash of parameters representing the request.

LICENSE AND COPYRIGHT

Copyright (C) 2026 Google LLC

This program is released under the Apache 2.0 license.

2 POD Errors

The following errors were encountered while parsing the POD:

Around line 159:

You forgot a '=back' before '=head2'

Around line 185:

=back without =over