NAME

Application default credentials.

Google::Auth - Implements application default credentials and project ID detection.

VERSION

Version 0.02

SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

use Google::Auth;

my $gauth = Google::Auth->new();
...

EXPORT

A list of functions that can be exported. You can delete this section if you don't export anything, such as for a purely object-oriented module.

SUBROUTINES/METHODS

default( $scopes, $options )

Gets the default credentials for the current environment.

AUTHOR

C.J. Collier, <cjac at google.com>

BUGS

Please report any bugs or feature requests to bug-google-auth-library-perl at rt.cpan.org, or through the web interface at https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Google-Auth-Library-Perl. I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.

SUPPORT

You can find documentation for this module with the perldoc command.

perldoc Google::Auth

You can also look for information at:

ACKNOWLEDGEMENTS

LICENSE AND COPYRIGHT

Copyright 2020,2021 Google, LLC

This program is released under the following license: Apache 2.0