NAME
Google::Cloud::Kms::V1 - Client library for Google Cloud Services
SYNOPSIS
use Google::Cloud::Kms::V1;
use Google::Auth;
my $auth = Google::Auth->default();
# 1. High-performance gRPC Transport (Default)
my $grpc_client = Google::Cloud::Kms::V1->new(
credentials => $auth,
transport => 'grpc', # Optional: 'grpc' is default
);
# 2. HTTP/REST Transport
my $rest_client = Google::Cloud::Kms::V1->new(
credentials => $auth,
transport => 'rest',
);
# Execute service methods
my $res = $grpc_client->some_method( %params );
DESCRIPTION
Google::Cloud::Kms::V1 is an auto-generated client library for Google Cloud Services.
It provides a unified client interface supporting both high-performance HTTP/2 gRPC and HTTP/REST transports, with automatic Google Cloud Application Default Credentials (ADC) resolution and typed Protocol Buffers message handling.
SOURCE
Generated from the following Protocol Buffers schemas:
google/cloud/kms/v1/service.protogoogle/cloud/kms/v1/autokey.protogoogle/cloud/kms/v1/ekm_service.protogoogle/cloud/kms/v1/autokey_admin.protogoogle/cloud/kms/v1/hsm_management.protogoogle/cloud/kms/v1/resources.proto
CONSTRUCTOR
new
my $client = Google::Cloud::Kms::V1->new(
credentials => $auth, # Optional: Google::Auth object (defaults to ADC)
transport => 'grpc', # Optional: 'grpc' (default) or 'rest'
);
ATTRIBUTES
credentials
Returns or accepts the Google::Auth credentials object.
transport
Returns or accepts the active transport object (Google::gRPC::Client or Google::Cloud::REST::Client).
METHODS
METHODS
The following RPC methods are available in this client:
list_key_rings
Calls the RPC method
ListKeyRingson the service. Takes a hash of parameters representing the request.create_key_handle
Calls the RPC method
CreateKeyHandleon the service. Takes a hash of parameters representing the request.list_ekm_connections
Calls the RPC method
ListEkmConnectionson the service. Takes a hash of parameters representing the request.update_autokey_config
Calls the RPC method
UpdateAutokeyConfigon the service. Takes a hash of parameters representing the request.get_autokey_config
Calls the RPC method
GetAutokeyConfigon the service. Takes a hash of parameters representing the request.show_effective_autokey_config
Calls the RPC method
ShowEffectiveAutokeyConfigon the service. Takes a hash of parameters representing the request.list_single_tenant_hsm_instances
Calls the RPC method
ListSingleTenantHsmInstanceson the service. Takes a hash of parameters representing the request.
LICENSE AND COPYRIGHT
Copyright (C) 2026 Google LLC
This program is released under the Apache 2.0 license.